@@ -22,8 +22,14 @@ class AuthController extends BaseController
         if ($this->userSession->isLogged()) {
             $this->response->redirect($this->helper->url->to('DashboardController', 'show'));
         } else {
+            $showCaptcha = false;
+            if (! empty($values['username']) && $this->userLockingModel->hasCaptcha($values['username'])) {
+                $showCaptcha = true;
+            } elseif ($this->captchaModel->isLocked($this->request->getIpAddress())) {
+                $showCaptcha = true;
+            }
             $this->response->html($this->helper->layout->app('auth/index', array(
-                'captcha' => ! empty($values['username']) && $this->userLockingModel->hasCaptcha($values['username']),
+                'captcha' => $showCaptcha,
                 'errors' => $errors,
                 'values' => $values,
                 'no_layout' => true,
@@ -40,7 +46,11 @@ class AuthController extends BaseController
     public function check()
     {
         $values = $this->request->getValues();
-        session_set('hasRememberMe', ! empty($values['remember_me']));
+
+        if (REMEMBER_ME_AUTH) {
+            session_set('hasRememberMe', ! empty($values['remember_me']));
+        }
+
         list($valid, $errors) = $this->authValidator->validateForm($values);
 
         if ($valid) {
