@@ -20,7 +20,8 @@ class UserMentionFormatter extends BaseFormatter implements FormatterInterface
      * @param array $users
      * @return $this
      */
-    public function withUsers(array $users) {
+    public function withUsers(array $users)
+    {
         $this->users = $users;
         return $this;
     }
@@ -59,4 +60,4 @@ class UserMentionFormatter extends BaseFormatter implements FormatterInterface
 
         return $result;
     }
-}
\ No newline at end of file
+}
