@@ -1,6 +1,6 @@
 <?php
 
-return array(
+return [
     'number.decimals_separator' => ',',
     'number.thousands_separator' => '.',
     'None' => 'Ninguno',
@@ -529,7 +529,7 @@ return array(
     'RSD - Serbian dinar' => 'RSD - Dinar serbio',
     'CNY - Chinese Yuan' => 'CNY - Yuan Chino',
     'USD - US Dollar' => 'USD - Dólar estadounidense',
-    // 'VES - Venezuelan Bolívar' => '',
+    'VES - Venezuelan Bolívar' => 'VES - Bolívar Venezolano',
     'Destination column' => 'Columna destino',
     'Move the task to another column when assigned to a user' => 'Mover la tarea a otra columna cuando sea asignada a un usuario(a)',
     'Move the task to another column when assignee is cleared' => 'Mover la tarea a otra columna cuando se elimine la persona asignada',
@@ -769,7 +769,6 @@ return array(
     'Swimlane changed for task #%d' => 'Carril cambiado para la tarea #%d',
     'Assignee changed on task #%d' => 'Asignado cambiado en la tarea #%d',
     '%d overdue tasks' => '%d tareas pendientes',
-    'Task #%d is overdue' => 'La tarea #%d está atrasada',
     'No notification.' => 'Sin notificación.',
     'Mark all as read' => 'marcar todo como leido',
     'Mark as read' => 'Marcar como leído',
@@ -1400,70 +1399,75 @@ return array(
     'Reorder this column by assignee (Z-A)' => 'Reordenar esta columna por persona asignada (Z-A)',
     'Reorder this column by due date (ASC)' => 'Reordenar esta columna por fecha de vencimiento (ASC)',
     'Reorder this column by due date (DESC)' => 'Reordenar esta columna por fecha de vencimiento (DESC)',
-    // 'Reorder this column by id (ASC)' => '',
-    // 'Reorder this column by id (DESC)' => '',
+    'Reorder this column by id (ASC)' => 'Reordenar esta columna por id (ASC)',
+    'Reorder this column by id (DESC)' => 'Reordenar esta columna por id (DESC)',
     '%s moved the task #%d "%s" to the project "%s"' => '%s movió la tarea #%d "%s" al proyecto "%s',
     'Task #%d "%s" has been moved to the project "%s"' => 'La tarea #%d "%s" se movió al proyecto "%s',
     'Move the task to another column when the due date is less than a certain number of days' => 'Mueva la tarea a otra columna cuando la fecha de vencimiento sea inferior a un cierto número de días',
-    // 'Automatically update the start date when the task is moved away from a specific column' => '',
+    'Automatically update the start date when the task is moved away from a specific column' => 'Actualizar automáticamente la fecha de inicio cuando la tarea se mueve fuera de una columna específica',
     'HTTP Client:' => 'Cliente HTTP:',
-    // 'Assigned' => '',
-    // 'Task limits apply to each swimlane individually' => '',
-    // 'Column task limits apply to each swimlane individually' => '',
-    // 'Column task limits are applied to each swimlane individually' => '',
-    // 'Column task limits are applied across swimlanes' => '',
-    // 'Task limit: ' => '',
-    // 'Change to global tag' => '',
-    // 'Do you really want to make the tag "%s" global?' => '',
-    // 'Enable global tags for this project' => '',
-    // 'Group membership(s):' => '',
-    // '%s is a member of the following group(s): %s' => '',
-    // '%d/%d group(s) shown' => '',
-    // 'Subtask creation or modification' => '',
-    // 'Assign the task to a specific user when the task is moved to a specific swimlane' => '',
-    // 'Comment' => '',
-    // 'Collapse vertically' => '',
-    // 'Expand vertically' => '',
-    // 'MXN - Mexican Peso' => '',
-    // 'Estimated vs actual time per column' => '',
-    // 'HUF - Hungarian Forint' => '',
+    'Assigned' => 'Asignado',
+    'Task limits apply to each swimlane individually' => 'Los límites de tareas se aplican a cada carril de forma individual',
+    'Column task limits apply to each swimlane individually' => 'Los límites de tareas por columna se aplican a cada carril de forma individual',
+    'Column task limits are applied to each swimlane individually' => 'Los límites de tareas por columna se aplican a cada carril de forma individual',
+    'Column task limits are applied across swimlanes' => 'Los límites de tareas por columna se aplican a través de los carriles',
+    'Task limit: ' => 'Límite de tareas:',
+    'Change to global tag' => 'Cambiar a etiqueta global',
+    'Do you really want to make the tag "%s" global?' => '¿Realmente quieres hacer global la etiqueta "%s"?',
+    'Enable global tags for this project' => 'Habilitar etiquetas globales para este proyecto',
+    'Group membership(s):' => 'Membresía(s) de grupo:',
+    '%s is a member of the following group(s): %s' => '%s es miembro del(los) siguiente(s) grupo(s): %s',
+    '%d/%d group(s) shown' => '%d/%d grupo(s) mostrado(s)',
+    'Subtask creation or modification' => 'Creación o modificación de subtareas',
+    'Assign the task to a specific user when the task is moved to a specific swimlane' => 'Asignar la tarea a un usuario específico cuando la tarea se mueve a un carril específico',
+    'Comment' => 'Comentario',
+    'Collapse vertically' => 'Contraer verticalmente',
+    'Expand vertically' => 'Expandir verticalmente',
+    'MXN - Mexican Peso' => 'MXN - Peso Mexicano',
+    'Estimated vs actual time per column' => 'Tiempo estimado vs tiempo real por columna',
+    'HUF - Hungarian Forint' => 'HUF - Florín Húngaro',
     'XBT - Bitcoin' => 'XBT - Bitcoin',
-    // 'You must select a file to upload as your avatar!' => '',
-    // 'The file you uploaded is not a valid image! (Only *.gif, *.jpg, *.jpeg and *.png are allowed!)' => '',
-    // 'Automatically set the due date when the task is moved away from a specific column' => '',
-    // 'No other projects found.' => '',
-    // 'Please choose a project you want to copy the tasks from.' => '',
-    // 'Import Tasks' => '',
-    // 'Copy' => '',
-    // 'Tasks copied successfully.' => '',
-    // 'Unable to copy tasks.' => '',
-    // 'Theme' => '',
-    // 'Theme:' => '',
-    // 'Light theme' => '',
-    // 'Dark theme' => '',
-    // 'Automatic theme - Sync with system' => '',
-    // 'Application managers or more' => '',
-    // 'Administrators' => '',
-    // 'Visibility:' => '',
-    // 'Standard users' => '',
-    // 'Visibility is required' => '',
-    // 'The visibility should be an app role' => '',
-    // 'Reply' => '',
-    // '%s wrote: ' => '',
-    // 'Number of visible tasks in this column and swimlane' => '',
-    // 'Number of tasks in this swimlane' => '',
-    // 'Unable to find another subtask in progress, you can close this window.' => '',
-    // 'This theme is invalid' => '',
-    // 'This role is invalid' => '',
-    // 'This timezone is invalid' => '',
-    // 'This language is invalid' => '',
-    // 'This URL is invalid' => '',
-    // 'Date format invalid' => '',
-    // 'Time format invalid' => '',
-    // 'Invalid Mail transport' => '',
-    // 'Color invalid' => '',
-    // 'This value must be greater or equal to %d' => '',
-    // 'Add a BOM at the beginning of the file (required for Microsoft Excel)' => '',
-    // 'Just add these tag(s)' => '',
-    // 'Remove internal link(s)' => '',
-);
+    'You must select a file to upload as your avatar!' => '¡Debes seleccionar un archivo para subir como tu avatar!',
+    'The file you uploaded is not a valid image! (Only *.gif, *.jpg, *.jpeg and *.png are allowed!)' => '¡El archivo que subiste no es una imagen válida! (Solo se permiten *.gif, *.jpg, *.jpeg y *.png)',
+    'Automatically set the due date when the task is moved away from a specific column' => 'Establecer automáticamente la fecha de vencimiento cuando la tarea se mueve fuera de una columna específica',
+    'No other projects found.' => 'No se encontraron otros proyectos.',
+    'Tasks copied successfully.' => 'Tareas copiadas con éxito.',
+    'Unable to copy tasks.' => 'No se pudieron copiar las tareas.',
+    'Theme' => 'Tema',
+    'Theme:' => 'Tema:',
+    'Light theme' => 'Tema claro',
+    'Dark theme' => 'Tema oscuro',
+    'Automatic theme - Sync with system' => 'Tema automático - Sincronizar con el sistema',
+    'Application managers or more' => 'Gerentes de aplicación o más',
+    'Administrators' => 'Administradores',
+    'Visibility:' => 'Visibilidad:',
+    'Standard users' => 'Usuarios estándar',
+    'Visibility is required' => 'La visibilidad es obligatoria',
+    'The visibility should be an app role' => 'La visibilidad debe ser un rol de aplicación',
+    'Reply' => 'Responder',
+    '%s wrote: ' => '%s escribió:',
+    'Number of visible tasks in this column and swimlane' => 'Número de tareas visibles en esta columna y carril',
+    'Number of tasks in this swimlane' => 'Número de tareas en este carril',
+    'Unable to find another subtask in progress, you can close this window.' => 'No se puede encontrar otra subtarea en progreso, puede cerrar esta ventana.',
+    'This theme is invalid' => 'Este tema no es válido',
+    'This role is invalid' => 'Este rol no es válido',
+    'This timezone is invalid' => 'Esta zona horaria no es válida',
+    'This language is invalid' => 'Este idioma no es válido',
+    'This URL is invalid' => 'Esta URL no es válida',
+    'Date format invalid' => 'Formato de fecha inválido',
+    'Time format invalid' => 'Formato de hora inválido',
+    'Invalid Mail transport' => 'Transporte de correo inválido',
+    'Color invalid' => 'Color inválido',
+    'This value must be greater or equal to %d' => 'Este valor debe ser mayor o igual a %d',
+    'Add a BOM at the beginning of the file (required for Microsoft Excel)' => 'Agregar un BOM al principio del archivo (requerido para Microsoft Excel)',
+    'Just add these tag(s)' => 'Simplemente agregue esta(s) etiqueta(s)',
+    'Remove internal link(s)' => 'Eliminar enlace(s) interno(s)',
+    'Import tasks from another project' => 'Importar tareas de otro proyecto',
+    'Select the project to copy tasks from' => 'Seleccione el proyecto desde el que copiar tareas',
+    'The total maximum allowed attachments size is %sB.' => 'El tamaño total máximo permitido para los archivos adjuntos es %sB.',
+    'Add attachments' => 'Agregar archivos adjuntos',
+    'Task #%d "%s" is overdue' => 'La tarea #%d "%s" está vencida',
+    'Enable notifications by default for all new users' => 'Habilitar notificaciones por defecto para todos los nuevos usuarios',
+    // 'Assign the task to its creator for specific columns if no assignee is set manually' => '',
+    // 'Assign a task to the logged user on column change to specified column if no user is assigned' => '',
+];
