@@ -1,8 +1,8 @@
 <?php
 
-return array(
-    // 'number.decimals_separator' => '',
-    // 'number.thousands_separator' => '',
+return [
+    'number.decimals_separator' => '.',
+    'number.thousands_separator' => ',',
     'None' => '없음',
     'Edit' => '수정',
     'Remove' => '삭제',
@@ -525,11 +525,11 @@ return array(
     'INR - Indian Rupee' => 'INR - 인도 루피',
     'JPY - Japanese Yen' => 'JPY - 일본 엔',
     'NZD - New Zealand Dollar' => 'NZD - 뉴질랜드 달러',
-    // 'PEN - Peruvian Sol' => '',
+    'PEN - Peruvian Sol' => 'PEN - 페루 솔',
     'RSD - Serbian dinar' => 'RSD - 세르비아 디나르',
-    // 'CNY - Chinese Yuan' => '',
+    'CNY - Chinese Yuan' => 'CNY - 중국 위안',
     'USD - US Dollar' => 'USD - 미국 달러',
-    // 'VES - Venezuelan Bolívar' => '',
+    'VES - Venezuelan Bolívar' => 'VES - 베네수엘라 볼리바르',
     'Destination column' => '이동 후 컬럼',
     'Move the task to another column when assigned to a user' => '사용자의 할당을 하면 할일을 다른 컬럼에 이동',
     'Move the task to another column when assignee is cleared' => '사용자의 할당이 없어지면 할일을 다른 컬럼에 이동',
@@ -769,7 +769,6 @@ return array(
     'Swimlane changed for task #%d' => '#%d 할일의 스웜라인이 변경됩니다',
     'Assignee changed on task #%d' => '#%d 할일의 담당자가 변경됩니다',
     '%d overdue tasks' => '할일의 기한이 %d일 지났습니다',
-    'Task #%d is overdue' => '#%d 할일의 기한이 지났습니다',
     'No notification.' => '알림이 없습니다',
     'Mark all as read' => '모두 읽음',
     'Mark as read' => '읽음',
@@ -1193,277 +1192,282 @@ return array(
     'Moving a task is not permitted' => '할일 이동이 거부되었습니다.',
     'This value must be in the range %d to %d' => '값의 범위는 %d 부터 %d 까지 입니다.',
     'You are not allowed to move this task.' => '당신은 할일 이동이 거부되었습니다.',
-    // 'API User Access' => '',
-    // 'Preview' => '',
-    // 'Write' => '',
-    // 'Write your text in Markdown' => '',
-    // 'No personal API access token registered.' => '',
-    // 'Your personal API access token is "%s"' => '',
-    // 'Remove your token' => '',
-    // 'Generate a new token' => '',
-    // 'Showing %d-%d of %d' => '',
-    // 'Outgoing Emails' => '',
-    // 'Add or change currency rate' => '',
-    // 'Reference currency: %s' => '',
-    // 'Add custom filters' => '',
-    // 'Export' => '',
-    // 'Add link label' => '',
-    // 'Incompatible Plugins' => '',
-    // 'Compatibility' => '',
-    // 'Permissions and ownership' => '',
-    // 'Priorities' => '',
-    // 'Close this window' => '',
-    // 'Unable to upload this file.' => '',
-    // 'Import tasks' => '',
-    // 'Choose a project' => '',
-    // 'Profile' => '',
-    // 'Application role' => '',
-    // '%d invitations were sent.' => '',
-    // '%d invitation was sent.' => '',
-    // 'Unable to create this user.' => '',
-    // 'Kanboard Invitation' => '',
-    // 'Visible on dashboard' => '',
-    // 'Created at:' => '',
-    // 'Updated at:' => '',
-    // 'There is no custom filter.' => '',
-    // 'New User' => '',
-    // 'Authentication' => '',
-    // 'If checked, this user will use a third-party system for authentication.' => '',
-    // 'The password is necessary only for local users.' => '',
-    // 'You have been invited to register on Kanboard.' => '',
-    // 'Click here to join your team' => '',
-    // 'Invite people' => '',
-    // 'Emails' => '',
-    // 'Enter one email address by line.' => '',
-    // 'Add these people to this project' => '',
-    // 'Add this person to this project' => '',
-    // 'Sign-up' => '',
-    // 'Credentials' => '',
-    // 'New user' => '',
-    // 'This username is already taken' => '',
-    // 'Your profile must have a valid email address.' => '',
-    // 'TRL - Turkish Lira' => '',
-    // 'The project email is optional and could be used by several plugins.' => '',
-    // 'The project email must be unique across all projects' => '',
-    // 'The email configuration has been disabled by the administrator.' => '',
-    // 'Close this project' => '',
-    // 'Open this project' => '',
-    // 'Close a project' => '',
-    // 'Do you really want to close this project: "%s"?' => '',
-    // 'Reopen a project' => '',
-    // 'Do you really want to reopen this project: "%s"?' => '',
-    // 'This project is open' => '',
-    // 'This project is closed' => '',
-    // 'Unable to upload files, check the permissions of your data folder.' => '',
-    // 'Another category with the same name exists in this project' => '',
-    // 'Comment sent by email successfully.' => '',
-    // 'Sent by email to "%s" (%s)' => '',
-    // 'Unable to read uploaded file.' => '',
-    // 'Database uploaded successfully.' => '',
-    // 'Task sent by email successfully.' => '',
-    // 'There is no category in this project.' => '',
-    // 'Send by email' => '',
-    // 'Create and send a comment by email' => '',
-    // 'Subject' => '',
-    // 'Upload the database' => '',
-    // 'You could upload the previously downloaded Sqlite database (Gzip format).' => '',
-    // 'Database file' => '',
-    // 'Upload' => '',
-    // 'Your project must have at least one active swimlane.' => '',
-    // 'Project: %s' => '',
-    // 'Automatic action not found: "%s"' => '',
-    // '%d projects' => '',
-    // '%d project' => '',
-    // 'There is no project.' => '',
-    // 'Sort' => '',
-    // 'Project ID' => '',
-    // 'Project name' => '',
-    // 'Public' => '',
-    // 'Personal' => '',
-    // '%d tasks' => '',
-    // '%d task' => '',
-    // 'Task ID' => '',
-    // 'Assign automatically a color when due date is expired' => '',
-    // 'Total score in this column across all swimlanes' => '',
-    // 'HRK - Kuna' => '',
-    // 'ARS - Argentine Peso' => '',
-    // 'COP - Colombian Peso' => '',
-    // '%d groups' => '',
-    // '%d group' => '',
-    // 'Group ID' => '',
-    // 'External ID' => '',
-    // '%d users' => '',
-    // '%d user' => '',
-    // 'Hide subtasks' => '',
-    // 'Show subtasks' => '',
-    // 'Authentication Parameters' => '',
-    // 'API Access' => '',
-    // 'No users found.' => '',
-    // 'User ID' => '',
-    // 'Notifications are activated' => '',
-    // 'Notifications are disabled' => '',
-    // 'User disabled' => '',
-    // '%d notifications' => '',
-    // '%d notification' => '',
-    // 'There is no external integration installed.' => '',
-    // 'You are not allowed to update tasks assigned to someone else.' => '',
-    // 'You are not allowed to change the assignee.' => '',
-    // 'Task suppression is not permitted' => '',
-    // 'Changing assignee is not permitted' => '',
-    // 'Update only assigned tasks is permitted' => '',
-    // 'Only for tasks assigned to the current user' => '',
-    // 'My projects' => '',
-    // 'You are not a member of any project.' => '',
-    // 'My subtasks' => '',
-    // '%d subtasks' => '',
-    // '%d subtask' => '',
-    // 'Only moving task between those columns is permitted for tasks assigned to the current user' => '',
-    // '[DUPLICATE]' => '',
-    // 'DKK - Danish Krona' => '',
-    // 'Remove user from group' => '',
-    // 'Assign the task to its creator' => '',
-    // 'This task was sent by email to "%s" with subject "%s".' => '',
-    // 'Predefined Email Subjects' => '',
-    // 'Write one subject by line.' => '',
-    // 'Create another link' => '',
-    // 'BRL - Brazilian Real' => '',
-    // 'Add a new Kanboard task' => '',
-    // 'Subtask not started' => '',
-    // 'Subtask currently in progress' => '',
-    // 'Subtask completed' => '',
-    // 'Subtask added successfully.' => '',
-    // '%d subtasks added successfully.' => '',
-    // 'Enter one subtask by line.' => '',
-    // 'Predefined Contents' => '',
-    // 'Predefined contents' => '',
-    // 'Predefined Task Description' => '',
-    // 'Do you really want to remove this template? "%s"' => '',
-    // 'Add predefined task description' => '',
-    // 'Predefined Task Descriptions' => '',
-    // 'Template created successfully.' => '',
-    // 'Unable to create this template.' => '',
-    // 'Template updated successfully.' => '',
-    // 'Unable to update this template.' => '',
-    // 'Template removed successfully.' => '',
-    // 'Unable to remove this template.' => '',
-    // 'Template for the task description' => '',
-    // 'The start date is greater than the end date' => '',
-    // 'Tags must be separated by a comma' => '',
-    // 'Only the task title is required' => '',
-    // 'Creator Username' => '',
-    // 'Color Name' => '',
-    // 'Column Name' => '',
-    // 'Swimlane Name' => '',
-    // 'Time Estimated' => '',
-    // 'Time Spent' => '',
-    // 'External Link' => '',
-    // 'This feature enables the iCal feed, RSS feed and the public board view.' => '',
-    // 'Stop the timer of all subtasks when moving a task to another column' => '',
-    // 'Subtask Title' => '',
-    // 'Add a subtask and activate the timer when moving a task to another column' => '',
-    // 'days' => '',
-    // 'minutes' => '',
-    // 'seconds' => '',
-    // 'Assign automatically a color when preset start date is reached' => '',
-    // 'Move the task to another column once a predefined start date is reached' => '',
-    // 'This task is now linked to the task %s with the relation "%s"' => '',
-    // 'The link with the relation "%s" to the task %s has been removed' => '',
-    // 'Custom Filter:' => '',
-    // 'Unable to find this group.' => '',
-    // '%s moved the task #%d to the column "%s"' => '',
-    // '%s moved the task #%d to the position %d in the column "%s"' => '',
-    // '%s moved the task #%d to the swimlane "%s"' => '',
-    // '%sh spent' => '',
-    // '%sh estimated' => '',
-    // 'Select All' => '',
-    // 'Unselect All' => '',
-    // 'Apply action' => '',
-    // 'Move selected tasks to another column or swimlane' => '',
-    // 'Edit tasks in bulk' => '',
-    // 'Choose the properties that you would like to change for the selected tasks.' => '',
-    // 'Configure this project' => '',
-    // 'Start now' => '',
-    // '%s removed a file from the task #%d' => '',
-    // 'Attachment removed from task #%d: %s' => '',
-    // 'No color' => '',
-    // 'Attachment removed "%s"' => '',
-    // '%s removed a file from the task %s' => '',
-    // 'Move the task to another swimlane when assigned to a user' => '',
-    // 'Destination swimlane' => '',
-    // 'Assign a category when the task is moved to a specific swimlane' => '',
-    // 'Move the task to another swimlane when the category is changed' => '',
-    // 'Reorder this column by priority (ASC)' => '',
-    // 'Reorder this column by priority (DESC)' => '',
-    // 'Reorder this column by assignee and priority (ASC)' => '',
-    // 'Reorder this column by assignee and priority (DESC)' => '',
-    // 'Reorder this column by assignee (A-Z)' => '',
-    // 'Reorder this column by assignee (Z-A)' => '',
-    // 'Reorder this column by due date (ASC)' => '',
-    // 'Reorder this column by due date (DESC)' => '',
-    // 'Reorder this column by id (ASC)' => '',
-    // 'Reorder this column by id (DESC)' => '',
-    // '%s moved the task #%d "%s" to the project "%s"' => '',
-    // 'Task #%d "%s" has been moved to the project "%s"' => '',
-    // 'Move the task to another column when the due date is less than a certain number of days' => '',
-    // 'Automatically update the start date when the task is moved away from a specific column' => '',
-    // 'HTTP Client:' => '',
-    // 'Assigned' => '',
-    // 'Task limits apply to each swimlane individually' => '',
-    // 'Column task limits apply to each swimlane individually' => '',
-    // 'Column task limits are applied to each swimlane individually' => '',
-    // 'Column task limits are applied across swimlanes' => '',
-    // 'Task limit: ' => '',
-    // 'Change to global tag' => '',
-    // 'Do you really want to make the tag "%s" global?' => '',
-    // 'Enable global tags for this project' => '',
-    // 'Group membership(s):' => '',
-    // '%s is a member of the following group(s): %s' => '',
-    // '%d/%d group(s) shown' => '',
-    // 'Subtask creation or modification' => '',
-    // 'Assign the task to a specific user when the task is moved to a specific swimlane' => '',
-    // 'Comment' => '',
-    // 'Collapse vertically' => '',
-    // 'Expand vertically' => '',
-    // 'MXN - Mexican Peso' => '',
-    // 'Estimated vs actual time per column' => '',
-    // 'HUF - Hungarian Forint' => '',
-    // 'XBT - Bitcoin' => '',
-    // 'You must select a file to upload as your avatar!' => '',
-    // 'The file you uploaded is not a valid image! (Only *.gif, *.jpg, *.jpeg and *.png are allowed!)' => '',
-    // 'Automatically set the due date when the task is moved away from a specific column' => '',
-    // 'No other projects found.' => '',
-    // 'Please choose a project you want to copy the tasks from.' => '',
-    // 'Import Tasks' => '',
-    // 'Copy' => '',
-    // 'Tasks copied successfully.' => '',
-    // 'Unable to copy tasks.' => '',
-    // 'Theme' => '',
-    // 'Theme:' => '',
-    // 'Light theme' => '',
-    // 'Dark theme' => '',
-    // 'Automatic theme - Sync with system' => '',
-    // 'Application managers or more' => '',
-    // 'Administrators' => '',
-    // 'Visibility:' => '',
-    // 'Standard users' => '',
-    // 'Visibility is required' => '',
-    // 'The visibility should be an app role' => '',
-    // 'Reply' => '',
-    // '%s wrote: ' => '',
-    // 'Number of visible tasks in this column and swimlane' => '',
-    // 'Number of tasks in this swimlane' => '',
-    // 'Unable to find another subtask in progress, you can close this window.' => '',
-    // 'This theme is invalid' => '',
-    // 'This role is invalid' => '',
-    // 'This timezone is invalid' => '',
-    // 'This language is invalid' => '',
-    // 'This URL is invalid' => '',
-    // 'Date format invalid' => '',
-    // 'Time format invalid' => '',
-    // 'Invalid Mail transport' => '',
-    // 'Color invalid' => '',
-    // 'This value must be greater or equal to %d' => '',
-    // 'Add a BOM at the beginning of the file (required for Microsoft Excel)' => '',
-    // 'Just add these tag(s)' => '',
-    // 'Remove internal link(s)' => '',
-);
+    'API User Access' => 'API 사용자 접근',
+    'Preview' => '미리 보기',
+    'Write' => '쓰기',
+    'Write your text in Markdown' => '마크다운으로 텍스트 작성',
+    'No personal API access token registered.' => '개인 API 접근 토큰이 등록되지 않았습니다.',
+    'Your personal API access token is "%s"' => '개인 API 접근 토큰은 "%s"입니다.',
+    'Remove your token' => '토큰 제거',
+    'Generate a new token' => '새 토큰 생성',
+    'Showing %d-%d of %d' => '%d-%d/%d 표시',
+    'Outgoing Emails' => '발신 이메일',
+    'Add or change currency rate' => '환율 추가 또는 변경',
+    'Reference currency: %s' => '기준 통화: %s',
+    'Add custom filters' => '사용자 정의 필터 추가',
+    'Export' => '내보내기',
+    'Add link label' => '링크 레이블 추가',
+    'Incompatible Plugins' => '호환되지 않는 플러그인',
+    'Compatibility' => '호환성',
+    'Permissions and ownership' => '권한 및 소유권',
+    'Priorities' => '우선 순위',
+    'Close this window' => '이 창 닫기',
+    'Unable to upload this file.' => '이 파일을 업로드할 수 없습니다.',
+    'Import tasks' => '작업 가져오기',
+    'Choose a project' => '프로젝트 선택',
+    'Profile' => '프로필',
+    'Application role' => '애플리케이션 역할',
+    '%d invitations were sent.' => '초대 %d건이 발송되었습니다.',
+    '%d invitation was sent.' => '초대 %d건이 발송되었습니다.',
+    'Unable to create this user.' => '이 사용자를 생성할 수 없습니다.',
+    'Kanboard Invitation' => 'Kanboard 초대',
+    'Visible on dashboard' => '대시보드에 표시',
+    'Created at:' => '생성 시간:',
+    'Updated at:' => '업데이트 시간:',
+    'There is no custom filter.' => '사용자 정의 필터가 없습니다.',
+    'New User' => '새 사용자',
+    'Authentication' => '인증',
+    'If checked, this user will use a third-party system for authentication.' => '선택하면 이 사용자는 타사 시스템을 사용하여 인증됩니다.',
+    'The password is necessary only for local users.' => '비밀번호는 로컬 사용자에게만 필요합니다.',
+    'You have been invited to register on Kanboard.' => 'Kanboard에 등록하도록 초대되었습니다.',
+    'Click here to join your team' => '팀에 참가하려면 여기를 클릭하세요',
+    'Invite people' => '사람 초대',
+    'Emails' => '이메일',
+    'Enter one email address by line.' => '한 줄에 하나의 이메일 주소를 입력하세요.',
+    'Add these people to this project' => '이 사람들을 이 프로젝트에 추가',
+    'Add this person to this project' => '이 사람을 이 프로젝트에 추가',
+    'Sign-up' => '가입',
+    'Credentials' => '자격 증명',
+    'New user' => '새 사용자',
+    'This username is already taken' => '이 사용자 이름은 이미 사용 중입니다.',
+    'Your profile must have a valid email address.' => '프로필에 유효한 이메일 주소가 있어야 합니다.',
+    'TRL - Turkish Lira' => 'TRL - 터키 리라',
+    'The project email is optional and could be used by several plugins.' => '프로젝트 이메일은 선택 사항이며 여러 플러그인에서 사용할 수 있습니다.',
+    'The project email must be unique across all projects' => '프로젝트 이메일은 모든 프로젝트에서 고유해야 합니다.',
+    'The email configuration has been disabled by the administrator.' => '이메일 설정은 관리자에 의해 비활성화되었습니다.',
+    'Close this project' => '이 프로젝트 닫기',
+    'Open this project' => '이 프로젝트 열기',
+    'Close a project' => '프로젝트 닫기',
+    'Do you really want to close this project: "%s"?' => '이 프로젝트를 정말로 닫으시겠습니까: "%s"?',
+    'Reopen a project' => '프로젝트 다시 열기',
+    'Do you really want to reopen this project: "%s"?' => '이 프로젝트를 정말로 다시 여시겠습니까: "%s"?',
+    'This project is open' => '이 프로젝트는 열려 있습니다.',
+    'This project is closed' => '이 프로젝트는 닫혀 있습니다.',
+    'Unable to upload files, check the permissions of your data folder.' => '파일을 업로드할 수 없습니다. 데이터 폴더의 권한을 확인하십시오.',
+    'Another category with the same name exists in this project' => '이 프로젝트에 같은 이름의 다른 카테고리가 있습니다.',
+    'Comment sent by email successfully.' => '이메일로 댓글을 성공적으로 보냈습니다.',
+    'Sent by email to "%s" (%s)' => '"%s" (%s)에게 이메일로 보냄',
+    'Unable to read uploaded file.' => '업로드된 파일을 읽을 수 없습니다.',
+    'Database uploaded successfully.' => '데이터베이스가 성공적으로 업로드되었습니다.',
+    'Task sent by email successfully.' => '작업이 이메일로 성공적으로 발송되었습니다.',
+    'There is no category in this project.' => '이 프로젝트에는 카테고리가 없습니다.',
+    'Send by email' => '이메일로 보내기',
+    'Create and send a comment by email' => '이메일로 댓글 작성 및 보내기',
+    'Subject' => '제목',
+    'Upload the database' => '데이터베이스 업로드',
+    'You could upload the previously downloaded Sqlite database (Gzip format).' => '이전에 다운로드한 Sqlite 데이터베이스(Gzip 형식)를 업로드할 수 있습니다.',
+    'Database file' => '데이터베이스 파일',
+    'Upload' => '업로드',
+    'Your project must have at least one active swimlane.' => '프로젝트에는 하나 이상의 활성 스윔레인이 있어야 합니다.',
+    'Project: %s' => '프로젝트: %s',
+    'Automatic action not found: "%s"' => '자동 액션을 찾을 수 없습니다: "%s"',
+    '%d projects' => '프로젝트 %d개',
+    '%d project' => '프로젝트 %d개',
+    'There is no project.' => '프로젝트가 없습니다.',
+    'Sort' => '정렬',
+    'Project ID' => '프로젝트 ID',
+    'Project name' => '프로젝트 이름',
+    'Public' => '공개',
+    'Personal' => '개인',
+    '%d tasks' => '작업 %d개',
+    '%d task' => '작업 %d개',
+    'Task ID' => '작업 ID',
+    'Assign automatically a color when due date is expired' => '마감일이 지났을 때 자동으로 색상 할당',
+    'Total score in this column across all swimlanes' => '모든 스윔레인에서 이 열의 총 점수',
+    'HRK - Kuna' => 'HRK - 쿠나',
+    'ARS - Argentine Peso' => 'ARS - 아르헨티나 페소',
+    'COP - Colombian Peso' => 'COP - 콜롬비아 페소',
+    '%d groups' => '그룹 %d개',
+    '%d group' => '그룹 %d개',
+    'Group ID' => '그룹 ID',
+    'External ID' => '외부 ID',
+    '%d users' => '사용자 %d명',
+    '%d user' => '사용자 %d명',
+    'Hide subtasks' => '하위 작업 숨기기',
+    'Show subtasks' => '하위 작업 표시',
+    'Authentication Parameters' => '인증 매개변수',
+    'API Access' => 'API 접근',
+    'No users found.' => '사용자를 찾을 수 없습니다.',
+    'User ID' => '사용자 ID',
+    'Notifications are activated' => '알림이 활성화되었습니다.',
+    'Notifications are disabled' => '알림이 비활성화되었습니다.',
+    'User disabled' => '사용자 비활성화됨',
+    '%d notifications' => '알림 %d개',
+    '%d notification' => '알림 %d개',
+    'There is no external integration installed.' => '설치된 외부 통합이 없습니다.',
+    'You are not allowed to update tasks assigned to someone else.' => '다른 사람에게 할당된 작업을 업데이트할 수 없습니다.',
+    'You are not allowed to change the assignee.' => '담당자를 변경할 수 없습니다.',
+    'Task suppression is not permitted' => '작업 삭제는 허용되지 않습니다.',
+    'Changing assignee is not permitted' => '담당자 변경은 허용되지 않습니다.',
+    'Update only assigned tasks is permitted' => '할당된 작업만 업데이트할 수 있습니다.',
+    'Only for tasks assigned to the current user' => '현재 사용자에게 할당된 작업에만 해당',
+    'My projects' => '내 프로젝트',
+    'You are not a member of any project.' => '어떤 프로젝트의 멤버도 아닙니다.',
+    'My subtasks' => '내 하위 작업',
+    '%d subtasks' => '하위 작업 %d개',
+    '%d subtask' => '하위 작업 %d개',
+    'Only moving task between those columns is permitted for tasks assigned to the current user' => '현재 사용자에게 할당된 작업의 경우 해당 열 간에만 작업 이동이 허용됩니다.',
+    '[DUPLICATE]' => '[복제]',
+    'DKK - Danish Krona' => 'DKK - 덴마크 크로네',
+    'Remove user from group' => '그룹에서 사용자 제거',
+    'Assign the task to its creator' => '작업을 생성자에게 할당',
+    'This task was sent by email to "%s" with subject "%s".' => '이 작업은 "%s"에게 제목 "%s"으로 이메일이 발송되었습니다.',
+    'Predefined Email Subjects' => '사전 정의된 이메일 제목',
+    'Write one subject by line.' => '한 줄에 하나의 제목을 작성하세요.',
+    'Create another link' => '다른 링크 생성',
+    'BRL - Brazilian Real' => 'BRL - 브라질 헤알',
+    'Add a new Kanboard task' => '새 Kanboard 작업 추가',
+    'Subtask not started' => '하위 작업 시작 안 함',
+    'Subtask currently in progress' => '하위 작업 현재 진행 중',
+    'Subtask completed' => '하위 작업 완료됨',
+    'Subtask added successfully.' => '하위 작업이 성공적으로 추가되었습니다.',
+    '%d subtasks added successfully.' => '하위 작업 %d개가 성공적으로 추가되었습니다.',
+    'Enter one subtask by line.' => '한 줄에 하나의 하위 작업을 입력하세요.',
+    'Predefined Contents' => '사전 정의된 내용',
+    'Predefined contents' => '사전 정의된 내용',
+    'Predefined Task Description' => '사전 정의된 작업 설명',
+    'Do you really want to remove this template? "%s"' => '정말로 이 템플릿을 제거하시겠습니까? "%s"',
+    'Add predefined task description' => '사전 정의된 작업 설명 추가',
+    'Predefined Task Descriptions' => '사전 정의된 작업 설명',
+    'Template created successfully.' => '템플릿이 성공적으로 생성되었습니다.',
+    'Unable to create this template.' => '이 템플릿을 생성할 수 없습니다.',
+    'Template updated successfully.' => '템플릿이 성공적으로 업데이트되었습니다.',
+    'Unable to update this template.' => '이 템플릿을 업데이트할 수 없습니다.',
+    'Template removed successfully.' => '템플릿이 성공적으로 제거되었습니다.',
+    'Unable to remove this template.' => '이 템플릿을 제거할 수 없습니다.',
+    'Template for the task description' => '작업 설명 템플릿',
+    'The start date is greater than the end date' => '시작 날짜가 종료 날짜보다 큽니다.',
+    'Tags must be separated by a comma' => '태그는 쉼표로 구분해야 합니다.',
+    'Only the task title is required' => '작업 제목만 필수입니다.',
+    'Creator Username' => '생성자 사용자 이름',
+    'Color Name' => '색상 이름',
+    'Column Name' => '열 이름',
+    'Swimlane Name' => '스윔레인 이름',
+    'Time Estimated' => '예상 시간',
+    'Time Spent' => '소요 시간',
+    'External Link' => '외부 링크',
+    'This feature enables the iCal feed, RSS feed and the public board view.' => '이 기능은 iCal 피드, RSS 피드 및 공개 보드 보기를 활성화합니다.',
+    'Stop the timer of all subtasks when moving a task to another column' => '작업을 다른 열로 이동할 때 모든 하위 작업의 타이머 중지',
+    'Subtask Title' => '하위 작업 제목',
+    'Add a subtask and activate the timer when moving a task to another column' => '하위 작업을 추가하고 작업이 다른 열로 이동할 때 타이머 활성화',
+    'days' => '일',
+    'minutes' => '분',
+    'seconds' => '초',
+    'Assign automatically a color when preset start date is reached' => '사전 설정된 시작 날짜에 도달하면 자동으로 색상 할당',
+    'Move the task to another column once a predefined start date is reached' => '사전 정의된 시작 날짜에 도달하면 작업을 다른 열로 이동',
+    'This task is now linked to the task %s with the relation "%s"' => '이 작업은 이제 "%s" 관계를 사용하여 작업 %s에 연결되었습니다.',
+    'The link with the relation "%s" to the task %s has been removed' => '작업 %s에 대한 "%s" 관계의 링크가 제거되었습니다.',
+    'Custom Filter:' => '사용자 정의 필터:',
+    'Unable to find this group.' => '이 그룹을 찾을 수 없습니다.',
+    '%s moved the task #%d to the column "%s"' => '%s이(가) 작업 #%d을(를) "%s" 열(로)로 이동했습니다.',
+    '%s moved the task #%d to the position %d in the column "%s"' => '%s이(가) 작업 #%d을(를) "%s" 열의 %d 위치(으)로 이동했습니다.',
+    '%s moved the task #%d to the swimlane "%s"' => '%s이(가) 작업 #%d을(를) "%s" 스윔레인(으)로 이동했습니다.',
+    '%sh spent' => '%sh 소요',
+    '%sh estimated' => '%sh 예상',
+    'Select All' => '모두 선택',
+    'Unselect All' => '모두 선택 해제',
+    'Apply action' => '작업 적용',
+    'Move selected tasks to another column or swimlane' => '선택한 작업을 다른 열 또는 스윔레인으로 이동',
+    'Edit tasks in bulk' => '작업 일괄 편집',
+    'Choose the properties that you would like to change for the selected tasks.' => '선택한 작업에 대해 변경하려는 속성을 선택하십시오.',
+    'Configure this project' => '이 프로젝트 구성',
+    'Start now' => '지금 시작',
+    '%s removed a file from the task #%d' => '%s이(가) 작업 #%d에서 파일을 제거했습니다.',
+    'Attachment removed from task #%d: %s' => '작업 #%d에서 첨부 파일 제거됨: %s',
+    'No color' => '색상 없음',
+    'Attachment removed "%s"' => '첨부 파일 "%s" 제거됨',
+    '%s removed a file from the task %s' => '%s이(가) 작업 %s에서 파일을 제거했습니다.',
+    'Move the task to another swimlane when assigned to a user' => '사용자에게 할당될 때 작업을 다른 스윔레인으로 이동',
+    'Destination swimlane' => '대상 스윔레인',
+    'Assign a category when the task is moved to a specific swimlane' => '작업이 특정 스윔레인으로 이동될 때 카테고리 할당',
+    'Move the task to another swimlane when the category is changed' => '카테고리가 변경될 때 작업을 다른 스윔레인으로 이동',
+    'Reorder this column by priority (ASC)' => '이 열을 우선순위로 재정렬 (오름차순)',
+    'Reorder this column by priority (DESC)' => '이 열을 우선순위로 재정렬 (내림차순)',
+    'Reorder this column by assignee and priority (ASC)' => '이 열을 담당자 및 우선순위로 재정렬 (오름차순)',
+    'Reorder this column by assignee and priority (DESC)' => '이 열을 담당자 및 우선순위로 재정렬 (내림차순)',
+    'Reorder this column by assignee (A-Z)' => '이 열을 담당자 (A-Z)로 재정렬',
+    'Reorder this column by assignee (Z-A)' => '이 열을 담당자 (Z-A)로 재정렬',
+    'Reorder this column by due date (ASC)' => '이 열을 마감일로 재정렬 (오름차순)',
+    'Reorder this column by due date (DESC)' => '이 열을 마감일로 재정렬 (내림차순)',
+    'Reorder this column by id (ASC)' => '이 열을 ID로 재정렬 (오름차순)',
+    'Reorder this column by id (DESC)' => '이 열을 ID로 재정렬 (내림차순)',
+    '%s moved the task #%d "%s" to the project "%s"' => '%s이(가) 작업 #%d "%s"을(를) 프로젝트 "%s"(으)로 이동했습니다.',
+    'Task #%d "%s" has been moved to the project "%s"' => '작업 #%d "%s"이(가) 프로젝트 "%s"(으)로 이동되었습니다.',
+    'Move the task to another column when the due date is less than a certain number of days' => '마감일이 특정 일수 미만일 때 작업을 다른 열로 이동',
+    'Automatically update the start date when the task is moved away from a specific column' => '작업이 특정 열에서 이동될 때 시작 날짜 자동 업데이트',
+    'HTTP Client:' => 'HTTP 클라이언트:',
+    'Assigned' => '할당됨',
+    'Task limits apply to each swimlane individually' => '작업 제한은 각 스윔레인에 개별적으로 적용됩니다.',
+    'Column task limits apply to each swimlane individually' => '열 작업 제한은 각 스윔레인에 개별적으로 적용됩니다.',
+    'Column task limits are applied to each swimlane individually' => '열 작업 제한은 각 스윔레인에 개별적으로 적용됩니다.',
+    'Column task limits are applied across swimlanes' => '열 작업 제한은 스윔레인 전반에 적용됩니다.',
+    'Task limit: ' => '작업 제한:',
+    'Change to global tag' => '글로벌 태그로 변경',
+    'Do you really want to make the tag "%s" global?' => '정말로 태그 "%s"를 글로벌로 만드시겠습니까?',
+    'Enable global tags for this project' => '이 프로젝트에 대해 글로벌 태그 활성화',
+    'Group membership(s):' => '그룹 구성원:',
+    '%s is a member of the following group(s): %s' => '%s은(는) 다음 그룹의 구성원입니다: %s',
+    '%d/%d group(s) shown' => '그룹 %d/%d 표시됨',
+    'Subtask creation or modification' => '하위 작업 생성 또는 수정',
+    'Assign the task to a specific user when the task is moved to a specific swimlane' => '작업이 특정 스윔레인으로 이동될 때 특정 사용자에게 작업 할당',
+    'Comment' => '댓글',
+    'Collapse vertically' => '세로로 접기',
+    'Expand vertically' => '세로로 확장',
+    'MXN - Mexican Peso' => 'MXN - 멕시코 페소',
+    'Estimated vs actual time per column' => '열당 예상 시간 대 실제 시간',
+    'HUF - Hungarian Forint' => 'HUF - 헝가리 포린트',
+    'XBT - Bitcoin' => 'XBT - 비트코인',
+    'You must select a file to upload as your avatar!' => '아바타로 업로드할 파일을 선택해야 합니다!',
+    'The file you uploaded is not a valid image! (Only *.gif, *.jpg, *.jpeg and *.png are allowed!)' => '업로드한 파일은 유효한 이미지가 아닙니다! (*.gif, *.jpg, *.jpeg 및 *.png만 허용됩니다!)',
+    'Automatically set the due date when the task is moved away from a specific column' => '작업이 특정 열에서 이동될 때 마감일 자동 설정',
+    'No other projects found.' => '다른 프로젝트를 찾을 수 없습니다.',
+    'Tasks copied successfully.' => '작업이 성공적으로 복사되었습니다.',
+    'Unable to copy tasks.' => '작업을 복사할 수 없습니다.',
+    'Theme' => '테마',
+    'Theme:' => '테마:',
+    'Light theme' => '밝은 테마',
+    'Dark theme' => '어두운 테마',
+    'Automatic theme - Sync with system' => '자동 테마 - 시스템과 동기화',
+    'Application managers or more' => '애플리케이션 관리자 이상',
+    'Administrators' => '관리자',
+    'Visibility:' => '가시성:',
+    'Standard users' => '표준 사용자',
+    'Visibility is required' => '가시성은 필수입니다.',
+    'The visibility should be an app role' => '가시성은 앱 역할이어야 합니다.',
+    'Reply' => '답글',
+    '%s wrote: ' => '%s 작성: ',
+    'Number of visible tasks in this column and swimlane' => '이 열과 스윔레인에 표시되는 작업 수',
+    'Number of tasks in this swimlane' => '이 스윔레인의 작업 수',
+    'Unable to find another subtask in progress, you can close this window.' => '다른 진행 중인 하위 작업을 찾을 수 없습니다. 이 창을 닫을 수 있습니다.',
+    'This theme is invalid' => '이 테마는 유효하지 않습니다.',
+    'This role is invalid' => '이 역할은 유효하지 않습니다.',
+    'This timezone is invalid' => '이 시간대는 유효하지 않습니다.',
+    'This language is invalid' => '이 언어는 유효하지 않습니다.',
+    'This URL is invalid' => '이 URL은 유효하지 않습니다.',
+    'Date format invalid' => '잘못된 날짜 형식',
+    'Time format invalid' => '잘못된 시간 형식',
+    'Invalid Mail transport' => '잘못된 메일 전송',
+    'Color invalid' => '잘못된 색상',
+    'This value must be greater or equal to %d' => '이 값은 %d보다 크거나 같아야 합니다.',
+    'Add a BOM at the beginning of the file (required for Microsoft Excel)' => '파일 시작 부분에 BOM 추가 (Microsoft Excel에 필요)',
+    'Just add these tag(s)' => '이 태그(들)만 추가',
+    'Remove internal link(s)' => '내부 링크 제거',
+    'Import tasks from another project' => '다른 프로젝트에서 작업 가져오기',
+    'Select the project to copy tasks from' => '작업을 복사할 프로젝트 선택',
+    'The total maximum allowed attachments size is %sB.' => '허용되는 총 첨부 파일 최대 크기는 %sB입니다.',
+    'Add attachments' => '첨부 파일 추가',
+    'Task #%d "%s" is overdue' => '할일 #%d "%s"의 기한이 지났습니다',
+    'Enable notifications by default for all new users' => '모든 신규 사용자에 대해 기본적으로 알림 활성화',
+    // 'Assign the task to its creator for specific columns if no assignee is set manually' => '',
+    // 'Assign a task to the logged user on column change to specified column if no user is assigned' => '',
+];
