@@ -1,7 +1,8 @@
 <?php
 
-require_once __DIR__.'/../../Base.php';
+namespace KanboardTests\units\Core\Security;
 
+use KanboardTests\units\Base;
 use Kanboard\Core\Security\Token;
 
 class TokenTest extends Base
