@@ -1,12 +1,13 @@
 <?php
 
+namespace KanboardTests\units\Formatter;
+
+use KanboardTests\units\Base;
 use Kanboard\Formatter\TaskAutoCompleteFormatter;
 use Kanboard\Model\ProjectModel;
 use Kanboard\Model\TaskCreationModel;
 use Kanboard\Model\TaskFinderModel;
 
-require_once __DIR__.'/../Base.php';
-
 class TaskAutoCompleteFormatterTest extends Base
 {
     public function testFormat()
